package cn.com.infosec.asn1.icao;

import cn.com.infosec.asn1.ASN1Encodable;
import cn.com.infosec.asn1.ASN1EncodableVector;
import cn.com.infosec.asn1.ASN1Sequence;
import cn.com.infosec.asn1.DERInteger;
import cn.com.infosec.asn1.DERObject;
import cn.com.infosec.asn1.DERSequence;
import cn.com.infosec.asn1.x509.AlgorithmIdentifier;
import java.util.Enumeration;

public class LDSSecurityObject extends ASN1Encodable implements ICAOObjectIdentifiers {
   public static final int ub_DataGroups = 16;
   DERInteger version;
   AlgorithmIdentifier digestAlgorithmIdentifier;
   DataGroupHash[] datagroupHash;

   public static LDSSecurityObject getInstance(Object obj) {
      if (obj != null && !(obj instanceof LDSSecurityObject)) {
         if (obj instanceof ASN1Sequence) {
            return new LDSSecurityObject(ASN1Sequence.getInstance(obj));
         } else {
            throw new IllegalArgumentException("unknown object in getInstance: " + obj.getClass().getName());
         }
      } else {
         return (LDSSecurityObject)obj;
      }
   }

   public LDSSecurityObject(ASN1Sequence seq) {
      DERInteger var2;
      var2 = new DERInteger.<init>(0);
      this.version = var2;
      if (seq != null && seq.size() != 0) {
         Enumeration seq1;
         this.version = DERInteger.getInstance((seq1 = seq.getObjects()).nextElement());
         this.digestAlgorithmIdentifier = AlgorithmIdentifier.getInstance(seq1.nextElement());
         this.checkDatagroupHashSeqSize((seq = ASN1Sequence.getInstance(seq1.nextElement())).size());
         this.datagroupHash = new DataGroupHash[seq.size()];

         for(int var4 = 0; var4 < seq.size(); ++var4) {
            this.datagroupHash[var4] = DataGroupHash.getInstance(seq.getObjectAt(var4));
         }

      } else {
         throw new IllegalArgumentException("null or empty sequence passed.");
      }
   }

   public LDSSecurityObject(AlgorithmIdentifier digestAlgorithmIdentifier, DataGroupHash[] datagroupHash) {
      this.version = new DERInteger(0);
      this.digestAlgorithmIdentifier = digestAlgorithmIdentifier;
      this.datagroupHash = datagroupHash;
      this.checkDatagroupHashSeqSize(datagroupHash.length);
   }

   private void checkDatagroupHashSeqSize(int size) {
      if (size < 2 || size > 16) {
         throw new IllegalArgumentException("wrong size in DataGroupHashValues : not in (2..16)");
      }
   }

   public AlgorithmIdentifier getDigestAlgorithmIdentifier() {
      return this.digestAlgorithmIdentifier;
   }

   public DataGroupHash[] getDatagroupHash() {
      return this.datagroupHash;
   }

   public DERObject toASN1Object() {
      ASN1EncodableVector var1;
      ASN1EncodableVector var10000 = var1 = new ASN1EncodableVector;
      var1.<init>();
      var1.add(this.version);
      var10000.add(this.digestAlgorithmIdentifier);
      ASN1EncodableVector var2;
      var2 = new ASN1EncodableVector.<init>();

      DataGroupHash[] var4;
      for(int var3 = 0; var3 < (var4 = this.datagroupHash).length; ++var3) {
         var2.add(var4[var3]);
      }

      DERSequence var5;
      var5 = new DERSequence.<init>(var2);
      var1.add(var5);
      return new DERSequence(var1);
   }
}
